@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "player.h"
 
@@ -142,6 +126,7 @@ Player::Player(QObject *parent) : QObject(parent)
 
     initMpris();
     m_volume = MusicSettings::value("base.play.volume").toInt();
+    m_mute = MusicSettings::value("base.play.mute").toBool();
     /**
      *  初始获取音量，避免从dbus获取音量时，获取的值为初始值0
      * */
@@ -219,7 +204,8 @@ void Player::playMeta(MediaMeta meta)
                 //文件不存在提示
                 emit signalPlaybackStatusChanged(Player::Paused);
                 m_ActiveMeta = meta;
-                playNextMeta(false);
+                if (m_MetaList.size() > 1)
+                    playNextMeta(false);
                 INT_LAST_PROGRESS_FLAG = 0;
                 return;
             }
@@ -238,23 +224,42 @@ void Player::playMeta(MediaMeta meta)
 
         //延迟设置进度
         if (INT_LAST_PROGRESS_FLAG && m_ActiveMeta.hash == meta.hash) {
-            m_basePlayer->pause();
+            //这里静音似乎没有用处，此时sinkInput还未初始化完成
+            QTimer::singleShot(100, this, [ = ]() {
+                setDbusMuted();
+            });
+            m_basePlayer->pauseNew(); //此处只暂停，不关闭音频设备，防止后面打开失败
             qint64 lastOffset = m_ActiveMeta.offset;
             QTimer::singleShot(150, this, [ = ]() {//为了记录进度条生效，在加载的时候让音乐播放150ms
                 qDebug() << "seek last position:" << lastOffset;
                 m_basePlayer->setTime(lastOffset);
                 m_basePlayer->play();
+
+                QTimer *muteTimer = new QTimer(this);
+                muteTimer->setInterval(200);
+                connect(muteTimer, &QTimer::timeout, this, [=](){
+                    //  对于已经静音无法恢复的情况，在此通过dbus恢复
+                    bool bvalid = isValidDbusMute();
+                    if (bvalid) {
+                        QDBusInterface ainterface("com.deepin.daemon.Audio", m_sinkInputPath,
+                                                  "com.deepin.daemon.Audio.SinkInput",
+                                                  QDBusConnection::sessionBus());
+                        if (!ainterface.isValid())
+                            return ;
+
+                        QVariant mute = ainterface.property("Mute");
+                        if (mute.toBool()) {
+                            ainterface.call(QLatin1String("SetMute"), false);
+                        }
+                        muteTimer->stop();
+                        muteTimer->deleteLater();
+                    }
+                });
+                muteTimer->start();
             });
         }
         // 开始后点击播放另一首哥播放保证错误
         INT_LAST_PROGRESS_FLAG = 0;
-        /*************************
-         * mute to dbus
-         * ***********************/
-
-        QTimer::singleShot(100, this, [ = ]() {
-            setDbusMuted();
-        });
 
         DRecentData data;
         data.appName = Global::getAppName();
@@ -325,6 +330,8 @@ void Player::resume()
         m_fadeInAnimation->setDuration(sFadeInOutAnimationDuration);
         m_fadeInAnimation->start();
     }
+    if (Global::checkBoardVendorType())
+        m_basePlayer->resume();
 
     this->resetDBusMpris(m_ActiveMeta);
     m_mpris->setLoopStatus(Mpris::Playlist);
@@ -736,7 +743,7 @@ Player::PlaybackStatus Player::status()
         return PlaybackStatus::Playing;
     } else if (status == PlayerBase::Paused) {
         return PlaybackStatus::Paused;
-    } else if (status == PlayerBase::Stopped || status == PlayerBase::Idle) {
+    } else if (status == PlayerBase::Stopped || status == PlayerBase::Idle || status == PlayerBase::Ended) {
         return PlaybackStatus::Stopped;
     } else {
         return PlaybackStatus::InvalidPlaybackStatus;
@@ -821,6 +828,7 @@ void Player::setPosition(qlonglong position)
     if (m_basePlayer->time() == -1) {
         INT_LAST_PROGRESS_FLAG = 1;
         m_ActiveMeta.offset = position;
+        emit positionChanged(position,  m_ActiveMeta.length, 1);
     }
 
     if (m_basePlayer->length() == m_ActiveMeta.length) {
@@ -1073,7 +1081,8 @@ void Player::readSinkInputPath()
         QVariant nameV = DBusUtils::readDBusProperty("com.deepin.daemon.Audio", curPath.path(),
                                                      "com.deepin.daemon.Audio.SinkInput", "Icon");
 
-        if (!nameV.isValid() || nameV.toString() != "deepin-music") continue;
+        if (!nameV.isValid() || nameV.toString() != "deepin-music")
+            continue;
 
         m_sinkInputPath = curPath.path();
         break;
@@ -1130,6 +1139,8 @@ void Player::initPlayer()
         m_basePlayer = new VlcPlayer(this);
         qDebug() << __func__ << "VlcPlayer";
     }
+    m_basePlayer->setVolume(m_volume);
+    m_basePlayer->setMute(m_mute);
 
     m_timer = new QTimer(this);
     m_timer->setInterval(300);
