@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     Zhang Wenchao <zhangwenchao@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef QTPLAYER_H
 #define QTPLAYER_H
 #include "playerbase.h"
@@ -39,6 +24,8 @@ public:
     PlayerBase::PlayState state() override;
     void play() override;
     void pause() override;
+    void pauseNew() override;
+    void resume() override;
     void stop() override;
     int length() override; //播放总时长
     void setTime(qint64 time) override;
