@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <vlc/vlc.h>
 #include <vlc_common.h>
@@ -34,6 +18,8 @@
 
 #include <QDebug>
 
+extern int g_playbackStatus;
+
 typedef libvlc_media_player_t *(*vlc_media_player_new_function)(libvlc_instance_t *);
 typedef libvlc_event_manager_t *(*vlc_media_player_event_manager_function)(libvlc_media_player_t *);
 typedef void (*vlc_media_player_release_function)(libvlc_media_player_t *);
@@ -254,6 +240,18 @@ void VlcMediaPlayer::pause()
     VlcError::showErrmsg();
 }
 
+void VlcMediaPlayer::pauseNew()
+{
+    if (!_vlcMediaPlayer)
+        return;
+    vlc_media_player_can_pause_function vlc_media_player_can_pause = (vlc_media_player_can_pause_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_media_player_can_pause");
+    vlc_media_player_set_pause_function vlc_media_player_set_pause = (vlc_media_player_set_pause_function)VlcDynamicInstance::VlcFunctionInstance()->resolveSymbol("libvlc_media_player_set_pause");
+    if (vlc_media_player_can_pause(_vlcMediaPlayer))
+        vlc_media_player_set_pause(_vlcMediaPlayer, true);
+
+    VlcError::showErrmsg();
+}
+
 void VlcMediaPlayer::resume()
 {
     if (!_vlcMediaPlayer)
@@ -273,9 +271,9 @@ void VlcMediaPlayer::setTime(qint64 time)
      * ***************************************/
 #ifdef QT_DEBUG
     if (!(state() == Vlc::Buffering
-            || state() == Vlc::Playing
-            || state() == Vlc::Paused
-            ||  state() == Vlc::Opening))
+          || state() == Vlc::Playing
+          || state() == Vlc::Paused
+          || state() == Vlc::Opening))
         return;
 #else
     if (!(state() == Vlc::Buffering
@@ -381,7 +379,14 @@ void VlcMediaPlayer::libvlc_callback(const libvlc_event_t *event,
         emit core->backward();
         break;
     case libvlc_MediaPlayerEndReached:
-        emit core->end(); //play end
+        g_playbackStatus = 0;
+        if (core->_data.isEmpty()) {
+            emit core->end(); //play end
+        } else {
+            g_playbackStatus = 1;
+            // 设置当前进度时间、步进、总时间
+            emit core->endReached();
+        }
         break;
     case libvlc_MediaPlayerEncounteredError:
         emit core->error();
