@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "playlistview.h"
 
@@ -39,7 +23,6 @@
 #include <DDialog>
 #include <DDesktopServices>
 #include <DScrollBar>
-#include <DGuiApplicationHelper>
 #include <DLabel>
 #include "util/pinyinsearch.h"
 
@@ -120,7 +103,6 @@ PlayListView::PlayListView(const QString &hash, bool isPlayQueue, bool dragFlag,
     , m_listPageType(NullType)
     , m_dragFlag(dragFlag)
 {
-    //m_listPageType = NullType;
     m_IsPlayQueue = isPlayQueue;
     setObjectName("PlayListView");
 
@@ -130,6 +112,7 @@ PlayListView::PlayListView(const QString &hash, bool isPlayQueue, bool dragFlag,
 
     m_delegate = new PlayItemDelegate(this);
     setItemDelegate(m_delegate);
+    setViewportMargins(0, 0, 8, 0);
 
     setUniformItemSizes(true);
 
@@ -163,13 +146,6 @@ PlayListView::PlayListView(const QString &hash, bool isPlayQueue, bool dragFlag,
     m_pDetailShortcut->setContext(Qt::WidgetWithChildrenShortcut);
     m_pDetailShortcut->setKey(QKeySequence(QLatin1String("Ctrl+I")));
     connect(m_pDetailShortcut, &QShortcut::activated, this, &PlayListView::showDetailInfoDlg);
-//    //快捷移出歌单
-//    m_pRmvSongsShortcut = new QShortcut(this);
-//    m_pRmvSongsShortcut->setKey(QKeySequence(QLatin1String("Delete")));
-//    connect(m_pRmvSongsShortcut, SIGNAL(activated()), this, SLOT(slotRmvFromSongList()));
-//    //快捷显示菜单
-//    m_pShowMenuShortcut = new QShortcut(this);
-//    m_pShowMenuShortcut->setKey(QKeySequence(QLatin1String("Alt+M")));
 
     connect(Player::getInstance(), &Player::signalPlaybackStatusChanged,
             this, &PlayListView::slotPlaybackStatusChanged);
@@ -224,6 +200,10 @@ PlayListView::PlayListView(const QString &hash, bool isPlayQueue, bool dragFlag,
             this, &PlayListView::slotHScreen);
 
     connect(&m_dragScrollTimer, SIGNAL(timeout()), this, SLOT(slotUpdateDragScroll()));
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(),&DGuiApplicationHelper::sizeModeChanged,this, &PlayListView::slotSizeModeChanged);
+#endif
 }
 
 PlayListView::~PlayListView()
@@ -256,11 +236,6 @@ void PlayListView::reloadAllSonglist()
     this->setDataBySortType(mediaMetas, sortType);
 }
 
-//void PlayListView::setCurrentItem(QStandardItem *item)
-//{
-//    setCurrentIndex(m_model->indexFromItem(item));
-//}
-
 void PlayListView::initAllSonglist(const QString &hash)
 {
     m_currentHash = hash;
@@ -455,7 +430,21 @@ QPixmap PlayListView::getPlayPixmap(bool isSelect)
         color = DGuiApplicationHelper::instance()->applicationPalette().highlight().color();
     }
 
-    QImage playingImage = Player::getInstance()->playingIcon().pixmap(QSize(20, 20), QIcon::Active, QIcon::On).toImage();
+    QSize iconSize(20, 20);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // 播放图标缩小80%
+        iconSize.setWidth(16);
+        iconSize.setHeight(16);
+    }
+#endif
+    QPixmap playingPixmap = QPixmap(iconSize);
+    playingPixmap.fill(Qt::transparent);
+    QPainter painter(&playingPixmap);
+    painter.setPen(color);
+    Player::getInstance()->playingIcon().paint(&painter, QRect(0, 0, iconSize.width(), iconSize.height()),
+                                               Qt::AlignCenter, QIcon::Active, QIcon::On);
+    /*QImage playingImage = Player::getInstance()->playingIcon().pixmap(iconSize, QIcon::Active, QIcon::On).toImage();
     for (int i = 0; i < playingImage.width(); i++) {
         for (int j = 0; j < playingImage.height(); j++) {
             if (playingImage.pixelColor(i, j) != QColor(0, 0, 0, 0)) {
@@ -463,8 +452,9 @@ QPixmap PlayListView::getPlayPixmap(bool isSelect)
             }
         }
     }
-    QPixmap playingPixmap = QPixmap::fromImage(playingImage);
-//    update();
+    QPixmap playingPixmap = QPixmap::fromImage(playingImage);*/
+
+    //update();
     return playingPixmap;
 }
 
@@ -492,12 +482,6 @@ void PlayListView::playListChange()
     setUpdatesEnabled(true);
     update();
 }
-
-//void PlayListView::setCurrentHash(QString hash)
-//{
-//    m_currentHash = hash;
-//}
-
 QString PlayListView::getCurrentHash()
 {
     return m_currentHash;
@@ -646,12 +630,17 @@ void PlayListView::setViewModeFlag(QString hash, QListView::ViewMode mode)
     } else {
         if (mode == QListView::IconMode) {
             setGridSize(QSize(-1, -1));
-            setSpacing(0);
-            setIconSize(QSize(170, 210));
-            // 修改底部间距
-            setViewportMargins(0, 0, -35, 0);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+            if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+                setSpacing(5);
+                setViewportMargins(-1, 0, -35, 0);
+            } else
+#endif
+            {
+                setSpacing(10);
+                setViewportMargins(-5, 0, -35, 0);
+            }
         } else {
-            setIconSize(QSize(36, 36));
             setGridSize(QSize(-1, -1));
             setSpacing(0);
             // 修改顶部间距
@@ -1444,18 +1433,20 @@ void PlayListView::contextMenuEvent(QContextMenuEvent *event)
 
 QPixmap PlayListView::dragItemsPixmap()
 {
-    qreal scale = devicePixelRatio();
+    qreal scale = devicePixelRatioF();
     QModelIndexList modelIndexList = allSelectedIndexes();
 
-    int leftBorder = m_dragFlag ? 0 : DRAGICON_LEFTBORDER;
-    int topBorder = m_dragFlag ? 0 : DRAGICON_TOPBORDER;
+    int leftBorder = DRAGICON_LEFTBORDER;
+    int topBorder = DRAGICON_TOPBORDER;
     QFont font;
     font.setPixelSize(10);
     QFontMetrics fontMetrics(font);
     int textSize = fontMetrics.width(QString("%1").arg(modelIndexList.size()));
-    if (textSize < fontMetrics.height()) textSize = fontMetrics.height();
-    int testRadius = textSize / 2 + DRAGICON_TEXTBORDERSIZE;
-    QRect pixRect(0, 0, DRAGICON_SIZE + leftBorder + testRadius, DRAGICON_SIZE + testRadius + topBorder + 10);
+    if (textSize < fontMetrics.height())
+        textSize = fontMetrics.height();
+    int textRadius = textSize / 2 + DRAGICON_TEXTBORDERSIZE;
+
+    QRect pixRect(0, 0, DRAGICON_SIZE * scale + leftBorder + textRadius, DRAGICON_SIZE * scale + textRadius + topBorder + 10);
     QPixmap pixmap(pixRect.size() * scale);
     pixmap.setDevicePixelRatio(scale);
     pixmap.fill(Qt::transparent);
@@ -1463,10 +1454,13 @@ QPixmap PlayListView::dragItemsPixmap()
     painter.setRenderHint(QPainter::Antialiasing, true);
     painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
 
+    // painter.setPen(QColor("#ff0000"));
+    // painter.drawRect(pixRect);
+
     QMatrix matrix;
     matrix.rotate(180.0);
     painter.save();
-    painter.translate(leftBorder + DRAGICON_SIZE, topBorder + DRAGICON_SIZE);
+    painter.translate(leftBorder + DRAGICON_SIZE * scale, topBorder + DRAGICON_SIZE * scale);
     // 绘制图片
     for (int i = qMin(modelIndexList.size() - 1, 2); i >= 0; --i) {
         QStandardItem *newItem = m_model->itemFromIndex(modelIndexList.at(i));
@@ -1499,11 +1493,12 @@ QPixmap PlayListView::dragItemsPixmap()
     painter.save();
     painter.setPen(Qt::NoPen);
     painter.setBrush(Qt::red);
-    painter.drawEllipse(QRect(leftBorder + DRAGICON_SIZE - testRadius, topBorder + DRAGICON_SIZE - testRadius, testRadius * 2, testRadius * 2));
+    painter.drawEllipse(QRect(leftBorder + DRAGICON_SIZE * scale - textRadius, topBorder + DRAGICON_SIZE * scale - textRadius, textRadius * 2, textRadius * 2));
     painter.setPen(Qt::white);
     painter.setFont(font);
     painter.setBrush(Qt::black);
-    painter.drawText(QRect(leftBorder + DRAGICON_SIZE - textSize / 2, topBorder + DRAGICON_SIZE - textSize / 2, textSize, textSize), QString("%1").arg(modelIndexList.size()), QTextOption(Qt::AlignCenter));
+    painter.drawText(QRect(leftBorder + DRAGICON_SIZE * scale - textSize / 2, topBorder + DRAGICON_SIZE * scale - textSize / 2, textSize, textSize),
+                     QString("%1").arg(modelIndexList.size()), QTextOption(Qt::AlignCenter));
     painter.restore();
 
     return pixmap;
@@ -1519,13 +1514,6 @@ void PlayListView::startDrag(Qt::DropActions supportedActions)
         selection.append(QItemSelectionRange(index));
     }
 
-//    if (!modelIndexList.isEmpty())
-//        scrollTo(modelIndexList.first());
-
-//    setAutoScroll(false);
-//    DListView::startDrag(supportedActions);
-//    setAutoScroll(true);
-
     if (!selection.isEmpty()) {
         selectionModel()->select(selection, QItemSelectionModel::Select);
     }
@@ -1591,8 +1579,6 @@ void PlayListView::updateDropIndicator()
     QModelIndex indexDrop = m_model->index(curRow, 0);
     //刷新旧区域使dropIndicator消失
     update(rect());
-//    update(m_preIndex);
-//    update(indexDrop);
     m_preIndex = indexDrop;
 }
 
@@ -1615,7 +1601,7 @@ void PlayListView::slotUpdateDragScroll()
 {
     QPoint pos = QCursor::pos();
     pos = mapFromGlobal(pos);
-    auto curValue = verticalScrollBar()->value();
+    int curValue = verticalScrollBar()->value();
     // 向上滚动
     if (pos.y() < 20 && pos.y() > 0 && curValue > 0) {
         curValue -= 15;
@@ -1628,6 +1614,21 @@ void PlayListView::slotUpdateDragScroll()
     }
 }
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+void PlayListView::slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode)
+{
+    if (this->viewMode() != QListView::IconMode)
+        return;
+
+    if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
+        setSpacing(5);
+        setViewportMargins(-1, 0, -35, 0);
+    } else {
+        setSpacing(10);
+        setViewportMargins(-5, 0, -35, 0);
+    }
+}
+#endif
 void PlayListView::dragMoveEvent(QDragMoveEvent *event)
 {
     if (event->mimeData()->hasFormat("text/uri-list")) {
@@ -1774,21 +1775,6 @@ void PlayListView::mouseReleaseEvent(QMouseEvent *event)
     QListView::mouseReleaseEvent(event);
 }
 
-//void PlayListView::reflushItemMediaMeta(const MediaMeta &meta)
-//{
-//    for (int i = 0; i <  m_model->rowCount(); i++) {
-//        QModelIndex curIndex = m_model->index(i, 0);
-//        MediaMeta metaTemp = curIndex.data(Qt::UserRole).value<MediaMeta>();
-
-//        if (meta.hash == metaTemp.hash) {
-//            QVariant mediaMeta;
-//            mediaMeta.setValue(meta);
-//            m_model->setData(curIndex, mediaMeta, Qt::UserRole);
-//            break;
-//        }
-//    }
-//}
-
 void PlayListView::slotTextCodecMenuClicked(QAction *action)
 {
     QModelIndexList modelIndexList = allSelectedIndexes();
