@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "singerdelegate.h"
 #include "singerlistview.h"
@@ -39,7 +23,33 @@ QT_BEGIN_NAMESPACE
 extern Q_WIDGETS_EXPORT void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);
 QT_END_NAMESPACE
 
+DGUI_USE_NAMESPACE
 
+static inline int playPauseBtnSize()
+{
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            // 紧凑模式缩小到80%
+            return 40;
+        } else
+#endif
+        {
+            return 50;
+        }
+}
+
+static inline int heightTopMargin()
+{
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            // 紧凑模式缩小到80%
+            return 29;
+        } else
+#endif
+        {
+            return 36;
+        }
+}
 static inline int pixel2point(int pixel)
 {
     return pixel * 96 / 72;
@@ -73,11 +83,25 @@ QSize SingerDataDelegate::sizeHint(const QStyleOptionViewItem &option,
         if (CommonService::getInstance()->isTabletEnvironment()) {
             return QSize(200, 200);
         } else {
-            return QSize(150, 150);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+            if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+                return QSize(126, 126);
+            } else
+#endif
+            {
+                return QSize(150, 150);
+            }
         }
     } else {
-        auto baseSize = QStyledItemDelegate::sizeHint(option, index);
-        return QSize(baseSize.width(), 38);
+        QSize baseSize = QStyledItemDelegate::sizeHint(option, index);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            return QSize(baseSize.width(), 30);
+        } else
+#endif
+        {
+            return QSize(baseSize.width(), 38);
+        }
     }
 }
 
@@ -144,17 +168,17 @@ bool SingerDataDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, c
 
 void SingerDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    auto listview = qobject_cast<const SingerListView *>(option.widget);
+    const SingerListView *listview = qobject_cast<const SingerListView *>(option.widget);
     SingerInfo singertmp = index.data(Qt::UserRole).value<SingerInfo>();
 
     painter.setRenderHint(QPainter::Antialiasing);
     painter.setRenderHint(QPainter::HighQualityAntialiasing);
     painter.setRenderHint(QPainter::SmoothPixmapTransform);
 
-    auto background = option.palette.background();
+    QBrush background = option.palette.background();
     painter.fillRect(option.rect, background);
     // 绘制阴影
-    QRect shadowRect(option.rect.x() - 10, option.rect.y(), 158, 158);
+    QRect shadowRect(option.rect.x() - 10, option.rect.y(), option.rect.width() + 8, option.rect.height() + 8);
     QPainterPath roundRectShadowPath;
     roundRectShadowPath.addRoundRect(shadowRect, 8, 8);
     painter.save();
@@ -167,10 +191,9 @@ void SingerDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewI
     QPainterPath roundRectPath;
     roundRectPath.addRoundRect(rect, 10, 10);
     painter.setClipPath(roundRectPath);
-
     // 画背景图片
     QIcon opticon;
-    auto value = index.data(Qt::DecorationRole);
+    QVariant value = index.data(Qt::DecorationRole);
     if (value.type() == QVariant::Icon) {
         opticon = qvariant_cast<QIcon>(value);
     }
@@ -183,7 +206,7 @@ void SingerDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewI
     QPen borderPen(borderPenColor);
     borderPen.setWidthF(2);
     painter.setPen(borderPen);
-    painter.drawRoundRect(rect/*.adjusted(1, 1, -1, 1)*/, 10, 10);
+    painter.drawRoundRect(rect, 10, 10);
     painter.restore();
 
     bool playFlag = singertmp.musicinfos.keys().contains(Player::getInstance()->getActiveMeta().hash);
@@ -195,25 +218,31 @@ void SingerDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewI
         fillColor = "#000000";
         fillColor.setAlphaF(0.3);
     }
-    int startHeight = rect.y() + rect.height() - 56;
-    int fillAllHeight = 36;
-    int curFillSize = fillAllHeight;
-    QRect fillBlurRect(rect.x(), rect.y() + rect.height() - fillAllHeight, rect.width(), fillAllHeight);
+
+    int blurHeight = 36;
+    int playingBlurHeight = 72;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        blurHeight = 30;
+        playingBlurHeight = 58;
+    }
+#endif
+    int curBlurHeight = blurHeight;
+    QRect fillBlurRect(rect.x(), rect.y() + rect.height() - blurHeight, rect.width(), blurHeight);
 
     if (playFlag && (playStatue == Player::Playing)) {
-        fillBlurRect = QRect(rect.x(), rect.y() + rect.height() - 70, rect.width(), 76);
-        curFillSize = 70;
+        fillBlurRect = QRect(rect.x(), rect.y() + rect.height() - playingBlurHeight, rect.width(), 76);
+        curBlurHeight = playingBlurHeight;
     }
 
     // 设置模糊
-    QImage t_imageBlur = opticon.pixmap(rect.width(), rect.height()).toImage();
-    qreal t_ratioBlur = t_imageBlur.devicePixelRatioF();
-    curFillSize = static_cast<int>(curFillSize * t_ratioBlur);
-
-    t_imageBlur  = t_imageBlur.copy(0, rect.height() - curFillSize, t_imageBlur.width(), curFillSize);
+    QImage blurImage = opticon.pixmap(rect.width(), rect.height()).toImage();
+    qreal blurRatio = blurImage.devicePixelRatioF();
+    curBlurHeight = static_cast<int>(curBlurHeight * blurRatio);
+    blurImage  = blurImage.copy(0, rect.height() - curBlurHeight, blurImage.width(), curBlurHeight);
     QTransform old_transformBlur = painter.transform();
     painter.translate(fillBlurRect.topLeft());
-    qt_blurImage(&painter, t_imageBlur, 35, false, false);
+    qt_blurImage(&painter, blurImage, 35, false, false);
     painter.setTransform(old_transformBlur);
     painter.fillRect(fillBlurRect, fillColor);
 
@@ -221,64 +250,79 @@ void SingerDataDelegate::drawIconMode(QPainter &painter, const QStyleOptionViewI
     SingerListView *listview2 = qobject_cast<SingerListView *>(const_cast<QWidget *>(option.widget));
     if (playFlag && playStatue == Player::Playing) {
         if (option.state & QStyle::State_MouseOver) {
-            painter.drawPixmap(QRect(rect.x() + 56, rect.y() + 82, 36, 36), hoverSuspendImg);
+            painter.drawPixmap(QRect(rect.x() + (rect.width() - 36) / 2,
+                                     rect.y() + rect.height() - (playingBlurHeight + (playingBlurHeight - blurHeight - 36) / 2),
+                                     36, 36), hoverSuspendImg);
         } else {
             if (listview2) {
-                painter.drawPixmap(QRect(rect.x() + 64, rect.y() + 92, 20, 18), listview2->getPlayPixmap(true));
+                painter.drawPixmap(QRect(rect.x() + (rect.width() - 20) / 2,
+                                         rect.y() +  rect.height() - (playingBlurHeight + (playingBlurHeight - blurHeight - 50) / 2),
+                                         20, 18), listview2->getPlayPixmap(true));
             }
         }
     }
 
-
-    QRect fillRect(rect.x(), startHeight, rect.width(), fillAllHeight);
-
+    // 绘制歌手
     QFont fontT6 = DFontSizeManager::instance()->get(DFontSizeManager::T6);
-    painter.setFont(fontT6);
     QFontMetrics fm(fontT6);
+    QRect nameRect(rect.x(), rect.y() + rect.height() - blurHeight, rect.width(), blurHeight);
 
-    QRect nameFillRect(rect.x(), startHeight + 26, rect.width(), 24);
-    nameFillRect.adjust(8, 0, -7, 0);
-    auto nameText = fm.elidedText(singertmp.singerName.isEmpty() ? SingerListView::tr("Unknown artist") : singertmp.singerName, Qt::ElideMiddle, nameFillRect.width());
+    painter.setFont(fontT6);
+    nameRect.adjust(8, 0, -7, 0);
+    QString nameText = fm.elidedText(singertmp.singerName.isEmpty() ? SingerListView::tr("Unknown artist") : singertmp.singerName, Qt::ElideMiddle, nameRect.width());
     painter.setPen(Qt::white);
-    painter.drawText(nameFillRect, Qt::AlignLeft | Qt::AlignTop, nameText);
-
-    QBrush t_fillBrush(QColor(128, 128, 128, 0));
+    painter.drawText(nameRect, Qt::AlignLeft | Qt::AlignVCenter, nameText);
 
+    // 绘制播放按钮
     fillColor.setAlphaF(0.3);
     if (listview->getThemeType() == 2) {
         fillColor = "#000000";
     }
 
-    if (option.state & QStyle::State_Selected) {
-        t_fillBrush = QBrush(QColor(128, 128, 128, 90));
-    }
-
     if ((option.state & QStyle::State_MouseOver) && (!playFlag || playStatue == Player::Paused)) {
         painter.save();
-        QImage t_image = opticon.pixmap(rect.width(), rect.height()).toImage();
-        int t_ratio = static_cast<int>(t_image.devicePixelRatioF());
-        QRect t_imageRect(rect.width() / 2 - 25, rect.height() / 2 - 25, 60 * t_ratio, 60 * t_ratio);
-        t_image  = t_image.copy(t_imageRect);
-        QRect t_hoverRect(option.rect.x() + 50, option.rect.y() + 36, 50 * t_ratio, 50 * t_ratio);
+
+        int blurSize = 60;
+        int iconSize = 43;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            // 紧凑模式缩小到80%
+            blurSize = 48;
+            iconSize = 34;
+        }
+#endif
+
+        QImage blurImage = opticon.pixmap(rect.width(), rect.height()).toImage();
+        int t_ratio = static_cast<int>(blurImage.devicePixelRatioF());
+        QRect imageRect((rect.width() - blurSize) / 2, (rect.height() - blurSize) / 2,
+                          blurSize * t_ratio, blurSize * t_ratio);
+        blurImage  = blurImage.copy(imageRect);
+        QRect hoverRect(rect.x() + (rect.width() - playPauseBtnSize()) / 2, rect.y() + heightTopMargin(),
+                          playPauseBtnSize() * t_ratio, playPauseBtnSize() * t_ratio);
 
         QTransform old_transform = painter.transform();
-        painter.translate(t_hoverRect.topLeft());
-        //截取成圆
-        QPainterPath t_imageClipPath;
-        t_imageClipPath.addEllipse(QRect(0, 0, 50, 50));
-        painter.setClipPath(t_imageClipPath);
-
-        qt_blurImage(&painter, t_image, 30, false, false);
+        painter.translate(hoverRect.topLeft());
+        // 截取成圆
+        QPainterPath imageClipPath;
+        imageClipPath.addEllipse(QRect(0, 0, playPauseBtnSize(), playPauseBtnSize()));
+        painter.setClipPath(imageClipPath);
+        qt_blurImage(&painter, blurImage, 30, false, false);
         painter.setTransform(old_transform);
-        painter.fillRect(t_hoverRect, fillColor);
-
+        painter.fillRect(hoverRect, fillColor);
+        // 绘制图标
         QPixmap t_hoverPlayImg(hoverPlayImg);
         t_hoverPlayImg.setDevicePixelRatio(option.widget->devicePixelRatioF());
-//        t_hoverRect.adjust(0, 0, -7 * t_ratio, -7 * t_ratio);
-        QRect t_pixMapRect(rect.x() + 53, rect.y() + 40, 43, 43);
-        painter.drawPixmap(t_pixMapRect, t_hoverPlayImg);
+        QRect pixMapRect(hoverRect.x() + (hoverRect.width() - iconSize) / 2, hoverRect.y() + (hoverRect.height() - iconSize) / 2,
+                         iconSize, iconSize);
+        painter.drawPixmap(pixMapRect, t_hoverPlayImg);
         painter.restore();
     }
+
+    // 选中后
+    QBrush t_fillBrush(QColor(128, 128, 128, 0));
+    if (option.state & QStyle::State_Selected) {
+        t_fillBrush = QBrush(QColor(128, 128, 128, 90));
+    }
     painter.fillRect(option.rect, t_fillBrush);
 }
 
@@ -501,8 +545,8 @@ void SingerDataDelegate::touchDoubleClicked(const QStyleOptionViewItem &option,
 
 void SingerDataDelegate::drawListMode(QPainter &painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    auto listview = qobject_cast<const SingerListView *>(option.widget);
-    auto singertmp = index.data(Qt::UserRole).value<SingerInfo>();
+    const SingerListView *listview = qobject_cast<const SingerListView *>(option.widget);
+    SingerInfo singertmp = index.data(Qt::UserRole).value<SingerInfo>();
 
     QFont fontT9 = DFontSizeManager::instance()->get(DFontSizeManager::T9);
     QFont fontT6 = DFontSizeManager::instance()->get(DFontSizeManager::T6);
@@ -514,10 +558,10 @@ void SingerDataDelegate::drawListMode(QPainter &painter, const QStyleOptionViewI
     painter.setRenderHint(QPainter::HighQualityAntialiasing);
 
     QColor baseColor("#FFFFFF");
-    baseColor.setAlphaF(0.1);
     QColor alternateBaseColor("#000000");
-    alternateBaseColor.setAlphaF(0.02);
     QColor selecteColor("#000000");
+    baseColor.setAlphaF(0.1);
+    alternateBaseColor.setAlphaF(0.02);
     selecteColor.setAlphaF(0.10);
     if (listview->getThemeType() == 2) {
         baseColor.setAlphaF(0.05);
@@ -526,13 +570,12 @@ void SingerDataDelegate::drawListMode(QPainter &painter, const QStyleOptionViewI
         selecteColor.setAlphaF(0.20);
     }
 
-    auto background = (index.row() % 2) == 1 ? baseColor : alternateBaseColor;
+    QColor background = (index.row() % 2) == 1 ? baseColor : alternateBaseColor;
     int lrWidth = 10;
     if (!(option.state & QStyle::State_Selected) && !(option.state & QStyle::State_MouseOver)) {
         painter.save();
         painter.setPen(Qt::NoPen);
         painter.setBrush(background);
-        //painter->drawRect(option.rect);
         QRect selecteColorRect = option.rect.adjusted(lrWidth, 0, -lrWidth, 0);
         painter.drawRoundedRect(selecteColorRect, 8, 8);
         painter.restore();
@@ -575,18 +618,20 @@ void SingerDataDelegate::drawListMode(QPainter &painter, const QStyleOptionViewI
     }
 
     int rowCount = listview->model()->rowCount();
-    auto rowCountSize = QString::number(rowCount).size();
+    int rowCountSize = QString::number(rowCount).size();
     rowCountSize = qMax(rowCountSize, 2);
 
+    int iconSize = 32;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        iconSize = 26;
+    }
+#endif
+
     QFontMetrics songsFm(fontT9);
-// 采用右对齐画文字，这里不用计算距离
-//    auto tailwidth = pixel2point(songsFm.width("0000-00-00")) + PlayItemRightMargin  + 20;
-//    auto w = option.rect.width() - 0 - tailwidth;
-
-
-    QRect numRect(lrWidth + 10, option.rect.y() + 3, 32, 32);
-    auto icon = option.icon;
-    auto value = index.data(Qt::DecorationRole);
+    QRect numRect(lrWidth + 10, option.rect.y() + (option.rect.height() - iconSize ) / 2, iconSize, iconSize);
+    QIcon icon = option.icon;
+    QVariant value = index.data(Qt::DecorationRole);
     if (value.type() == QVariant::Icon) {
         icon = qvariant_cast<QIcon>(value);
     }
@@ -647,12 +692,12 @@ void SingerDataDelegate::mouseClicked(const QStyleOptionViewItem &option, const
     } else {
         int borderWidth = 10;
         QRect rect = option.rect.adjusted(borderWidth, borderWidth, -borderWidth, -borderWidth);
-        QRect hoverRect(rect.x() + 50, rect.y() + 36, 50, 50);
 
         QPainterPath imageClipPath;
-        imageClipPath.addEllipse(QRect(rect.x() + 50, rect.y() + 36, 50, 50));
+        imageClipPath.addEllipse(QRect(rect.x() + (rect.width() - playPauseBtnSize()) / 2, rect.y() + heightTopMargin(),
+                                       playPauseBtnSize(), playPauseBtnSize()));
         imageClipPath.closeSubpath();
-        auto fillPolygon = imageClipPath.toFillPolygon();
+        QPolygonF fillPolygon = imageClipPath.toFillPolygon();
 
         if (fillPolygon.containsPoint(pressPos, Qt::OddEvenFill)) {
             if (singertmp.musicinfos.values().size() > 0) {
