@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "singerlistview.h"
 
 #include <QDebug>
@@ -32,7 +17,6 @@
 #include <DDialog>
 #include <DDesktopServices>
 #include <DScrollBar>
-#include <DGuiApplicationHelper>
 
 #include "util/pinyinsearch.h"
 
@@ -43,7 +27,6 @@
 #include "global.h"
 #include "ac-desktop-define.h"
 
-DWIDGET_USE_NAMESPACE
 // 升序
 bool moreThanTimestampASC(SingerInfo v1, SingerInfo v2)
 {
@@ -127,13 +110,6 @@ SingerListView::SingerListView(const QString &hash, QWidget *parent)
     setBatchSize(2000);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-//    musicListDialog = new MusicListDialog("artist", this);
-//    AC_SET_OBJECT_NAME(musicListDialog, AC_musicListDialogSinger);
-//    AC_SET_ACCESSIBLE_NAME(musicListDialog, AC_musicListDialogSinger);
-
-// 双击逻辑位置移动
-//    connect(this, &SingerListView::doubleClicked, this, &SingerListView::onDoubleClicked);
-
     setSelectionMode(QListView::SingleSelection);
     setSelectionBehavior(QAbstractItemView::SelectRows);
 
@@ -170,6 +146,10 @@ SingerListView::SingerListView(const QString &hash, QWidget *parent)
         connect(CommonService::getInstance(), &CommonService::signalHScreen,
                 this, &SingerListView::slotHScreen);
     }
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(),&DGuiApplicationHelper::sizeModeChanged,this, &SingerListView::slotSizeModeChanged);
+#endif
 }
 
 SingerListView::~SingerListView()
@@ -375,13 +355,22 @@ void SingerListView::setViewModeFlag(QListView::ViewMode mode)
         }
     } else {
         if (mode == QListView::IconMode) {
-            setIconSize(QSize(150, 150));
+            //setIconSize(QSize(150, 150));
             setGridSize(QSize(-1, -1));
-            // 去除底部间距
-            setViewportMargins(-10, -13, -35, 0);
-            setSpacing(20);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+            if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+                setSpacing(15);
+                setViewportMargins(-5, -13, -35, 0);
+            } else
+#endif
+            {
+                setSpacing(20);
+                // 去除底部间距
+                setViewportMargins(-10, -13, -35, 0);
+            }
         } else {
-            setIconSize(QSize(36, 36));
+            //setIconSize(QSize(36, 36));
             setGridSize(QSize(-1, -1));
             // 修改顶部间距
             setViewportMargins(0, 0, 8, 0);
@@ -400,7 +389,6 @@ QListView::ViewMode SingerListView::getViewMode()
 void SingerListView::setThemeType(int type)
 {
     musicTheme = type;
-//    musicListDialog->setThemeType(type);
 }
 
 int SingerListView::getThemeType() const
@@ -408,25 +396,11 @@ int SingerListView::getThemeType() const
     return musicTheme;
 }
 
-//void SingerListView::setPlayPixmap(QPixmap pixmap, QPixmap sidebarPixmap, QPixmap albumPixmap)
-//{
-////    if (musciListDialog->isVisible())
-////        musciListDialog->setPlayPixmap(pixmap, sidebarPixmap);
-//    playingPix = pixmap;
-//    sidebarPix = sidebarPixmap;
-//    update();
-//}
-
 QPixmap SingerListView::getPlayPixmap() const
 {
     return playingPix;
 }
 
-//QPixmap SingerListView::getSidebarPixmap() const
-//{
-//    return sidebarPix;
-//}
-
 QPixmap SingerListView::getPlayPixmap(bool isSelect)
 {
     // 修改icon绘制方法为修改像素点颜色
@@ -583,19 +557,21 @@ void SingerListView::slotHScreen(bool isHScreen)
     }
 }
 
-// 区分单双击需要，双击逻辑位置移动
-//void SingerListView::onDoubleClicked(const QModelIndex &index)
-//{
-//    SingerInfo signerTmp = index.data(Qt::UserRole).value<SingerInfo>();
-//    // 原来的弹框修改为显示二级菜单
-////    musicListDialog->flushDialog(signerTmp.musicinfos, false);
-////    musicListDialog->exec();
-//    if (m_hash == "artist") {
-//        emit CommonService::getInstance()->signalShowSubSonglist(signerTmp.musicinfos, SingerType);
-//    } else if (m_hash == "artistResult") {
-//        emit CommonService::getInstance()->signalShowSubSonglist(signerTmp.musicinfos, SearchSingerResultType);
-//    }
-//}
+#ifdef DTKWIDGET_CLASS_DSizeMode
+void SingerListView::slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode)
+{
+    if (m_viewModel != QListView::IconMode)
+        return;
+
+    if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
+        setViewportMargins(-5, -13, -35, 0);
+        setSpacing(15);
+    } else {
+        setViewportMargins(-10, -13, -35, 0);
+        setSpacing(20);
+    }
+}
+#endif
 
 void SingerListView::slotCoverUpdate(const MediaMeta &meta)
 {
