@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "footerwidget.h"
 
@@ -87,6 +71,48 @@ FooterWidget::FooterWidget(QWidget *parent) :
     m_limitRepeatClick = new QTimer(this);
     m_limitRepeatClick->setSingleShot(true);
     m_limitRepeatClick->setInterval(200);
+
+    connect(&m_metaBufferDetector, &MetaBufferDetector::metaBuffer, m_waveform, &Waveform::onAudioBuffer);
+    connect(m_btPlayQueue, &DIconButton::clicked, this, &FooterWidget::slotPlayQueueClick);
+    connect(m_btLyric, &DIconButton::clicked, this, &FooterWidget::slotLrcClick);
+    connect(m_btPlayMode, &DIconButton::clicked, this, &FooterWidget::slotPlayModeClick);
+    connect(m_btCover, &MusicPixmapButton::clicked, this, &FooterWidget::slotCoverClick);
+    connect(m_btPlay, SIGNAL(clicked(bool)), this, SLOT(slotPlayClick(bool)));
+    connect(m_btNext, SIGNAL(clicked(bool)), this, SLOT(slotNextClick(bool)));
+    connect(m_btPrev, SIGNAL(clicked(bool)), this, SLOT(slotPreClick(bool)));
+    connect(m_btSound, &DIconButton::clicked, this, &FooterWidget::slotSoundClick);
+    connect(m_btSound, &ControlIconButton::mouseIn, this, &FooterWidget::slotSoundMouseIn);
+    connect(m_btFavorite, &DIconButton::clicked, this, &FooterWidget::slotFavoriteClick);
+    // 歌单数据改变时设置上下一首按钮状态
+    connect(Player::getInstance(), &Player::signalPlaylistCountChange, this, [ = ]() {
+        m_btNext->setEnabled(Player::getInstance()->getPlayList()->size() > 1);
+        m_btPrev->setEnabled(Player::getInstance()->getPlayList()->size() > 1);
+    });
+
+    connect(Player::getInstance(), &Player::signalPlaybackStatusChanged,
+            this, &FooterWidget::slotPlaybackStatusChanged);
+    connect(Player::getInstance(), &Player::signalMediaMetaChanged,
+            this, &FooterWidget::slotMediaMetaChanged);
+
+    connect(CommonService::getInstance(), &CommonService::signalFluashFavoriteBtnIcon, this, &FooterWidget::fluashFavoriteBtnIcon);
+    connect(CommonService::getInstance(), &CommonService::signalSetPlayModel, this, /*&FooterWidget::setPlayModel*/[=](Player::PlaybackMode playModel){
+        setPlayModel(playModel, true);
+    });
+    connect(CommonService::getInstance(), &CommonService::signalPlayQueueClosed, this, &FooterWidget::slotFlushBackground);
+    // dbus
+    connect(Player::getInstance()->getMpris(), &MprisPlayer::volumeRequested, this, &FooterWidget::slotDbusVolumeChanged);
+    connect(m_volSlider, &SoundVolume::delayAutoHide, this, [ = ]() {
+        m_btSound->setChecked(false);
+    });
+
+    connect(m_volSlider, &SoundVolume::sigVolumeChanged, this, &FooterWidget::slotFlushSoundIcon);
+    connect(DataBaseService::getInstance(), &DataBaseService::signalFavSongRemove, this, &FooterWidget::slotFavoriteRemove);
+    connect(DataBaseService::getInstance(), &DataBaseService::signalFavSongAdd, this, &FooterWidget::flushFavoriteBtnIconAdd);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    slotSizeModeChanged(DGuiApplicationHelper::instance()->sizeMode());
+    connect(DGuiApplicationHelper::instance(),&DGuiApplicationHelper::sizeModeChanged,this, &FooterWidget::slotSizeModeChanged);
+#endif
 }
 
 FooterWidget::~FooterWidget()
@@ -99,9 +125,9 @@ FooterWidget::~FooterWidget()
 
 void FooterWidget::initUI(QWidget *parent)
 {
-    auto backLayout = new QVBoxLayout(this);
-    backLayout->setSpacing(0);
-    backLayout->setContentsMargins(0, 0, 0, 0);
+//    QVBoxLayout *backLayout = new QVBoxLayout(this);
+//    backLayout->setSpacing(0);
+//    backLayout->setContentsMargins(0, 0, 0, 0);
 
     m_forwardWidget = new DBlurEffectWidget(this);
     m_forwardWidget->setBlurRectXRadius(18);
@@ -113,18 +139,10 @@ void FooterWidget::initUI(QWidget *parent)
     m_forwardWidget->setMaskColor(maskColor);
     slotFlushBackground();
 
-//    this->layout()->addWidget(m_forwardWidget);
-
-    auto mainHBoxlayout = new QHBoxLayout(m_forwardWidget);
+    QHBoxLayout *mainHBoxlayout = new QHBoxLayout(m_forwardWidget);
     mainHBoxlayout->setSpacing(10);
     mainHBoxlayout->setContentsMargins(10, 10, 10, 10);
 
-//    auto downWidget = new DWidget();
-//    downWidget->setStyleSheet("background-color:red;");
-//    auto layout = new QHBoxLayout(downWidget);
-//    layout->setContentsMargins(0, 0, 10, 0);
-//    mainVBoxlayout->addWidget(downWidget);
-
     m_btPrev = new DButtonBoxButton(QIcon(":/icons/deepin/builtin/texts/music_last_36px.svg"), "", this);
     m_btPrev->setIconSize(QSize(36, 36));
     m_btPrev->setObjectName("FooterActionPrev");
@@ -197,7 +215,6 @@ void FooterWidget::initUI(QWidget *parent)
     m_waveform->setValue(0);
     m_waveform->adjustSize();
     mainHBoxlayout->addWidget(m_waveform, 100);
-
     AC_SET_OBJECT_NAME(m_waveform, AC_Waveform);
     AC_SET_ACCESSIBLE_NAME(m_waveform, AC_Waveform);
 
@@ -279,18 +296,13 @@ void FooterWidget::initUI(QWidget *parent)
     m_volSlider->hide();
     m_volSlider->setProperty("DelayHide", true);
     m_volSlider->setProperty("NoDelayShow", true);
-
     // 设置静音
     if (MusicSettings::value("base.play.mute").toBool()) {
         Player::getInstance()->setMuted(true);
     }
-
     AC_SET_OBJECT_NAME(m_volSlider, AC_VolSlider);
     AC_SET_ACCESSIBLE_NAME(m_volSlider, AC_VolSlider);
 
-//    m_metaBufferDetector = new MetaBufferDetector(nullptr);
-    connect(&m_metaBufferDetector, &MetaBufferDetector::metaBuffer, m_waveform, &Waveform::onAudioBuffer);
-
     // 设置提示框
     m_hintFilter =  new HintFilter(this);
     installTipHint(m_btPrev, tr("Previous"));
@@ -299,50 +311,15 @@ void FooterWidget::initUI(QWidget *parent)
     installTipHint(m_btFavorite, tr("Favorite"));
     installTipHint(m_btLyric, tr("Lyrics"));
     installTipHint(m_btPlayQueue, tr("Play Queue"));
-    // 设置播放模式提示框
     installTipHint(m_btPlayMode, playModeStr(Player::getInstance()->mode()));
 
-    connect(m_btPlayQueue, &DIconButton::clicked, this, &FooterWidget::slotPlayQueueClick);
-    connect(m_btLyric, &DIconButton::clicked, this, &FooterWidget::slotLrcClick);
-    connect(m_btPlayMode, &DIconButton::clicked, this, &FooterWidget::slotPlayModeClick);
-    connect(m_btCover, &MusicPixmapButton::clicked, this, &FooterWidget::slotCoverClick);
-    connect(m_btPlay, SIGNAL(clicked(bool)), this, SLOT(slotPlayClick(bool)));
-    connect(m_btNext, SIGNAL(clicked(bool)), this, SLOT(slotNextClick(bool)));
-    connect(m_btPrev, SIGNAL(clicked(bool)), this, SLOT(slotPreClick(bool)));
-    connect(m_btSound, &DIconButton::clicked, this, &FooterWidget::slotSoundClick);
-    connect(m_btSound, &ControlIconButton::mouseIn, this, &FooterWidget::slotSoundMouseIn);
-    connect(m_btFavorite, &DIconButton::clicked, this, &FooterWidget::slotFavoriteClick);
-    // 歌单数据改变时设置上下一首按钮状态
-    connect(Player::getInstance(), &Player::signalPlaylistCountChange, this, [ = ]() {
-        m_btNext->setEnabled(Player::getInstance()->getPlayList()->size() > 1);
-        m_btPrev->setEnabled(Player::getInstance()->getPlayList()->size() > 1);
-    });
-
-    connect(Player::getInstance(), &Player::signalPlaybackStatusChanged,
-            this, &FooterWidget::slotPlaybackStatusChanged);
-    connect(Player::getInstance(), &Player::signalMediaMetaChanged,
-            this, &FooterWidget::slotMediaMetaChanged);
-
-    connect(CommonService::getInstance(), &CommonService::signalFluashFavoriteBtnIcon, this, &FooterWidget::fluashFavoriteBtnIcon);
-    connect(CommonService::getInstance(), &CommonService::signalSetPlayModel, this, &FooterWidget::setPlayModel);
-    connect(CommonService::getInstance(), &CommonService::signalPlayQueueClosed, this, &FooterWidget::slotFlushBackground);
-    // dbus
-    connect(Player::getInstance()->getMpris(), &MprisPlayer::volumeRequested, this, &FooterWidget::slotDbusVolumeChanged);
-    connect(m_volSlider, &SoundVolume::delayAutoHide, this, [ = ]() {
-        m_btSound->setChecked(false);
-    });
-
-    connect(m_volSlider, &SoundVolume::sigVolumeChanged, this, &FooterWidget::slotFlushSoundIcon);
-    connect(DataBaseService::getInstance(), &DataBaseService::signalFavSongRemove, this, &FooterWidget::slotFavoriteRemove);
-    connect(DataBaseService::getInstance(), &DataBaseService::signalFavSongAdd, this, &FooterWidget::flushFavoriteBtnIconAdd);
-
     slotFlushSoundIcon();
     resetBtnEnable();
 }
 
 void FooterWidget::installTipHint(QWidget *widget, const QString &hintstr)
 {
-    auto hintWidget = new ToolTips("", parentWidget()); //parentWidget()= mainframe
+    ToolTips *hintWidget = new ToolTips("", parentWidget()); //parentWidget()= mainframe
     hintWidget->hide();
     hintWidget->setText(hintstr);
     hintWidget->setFixedHeight(32);
@@ -356,7 +333,7 @@ void FooterWidget::moveVolSlider()
     m_volSlider->adjustSize();
     QSize sz = m_volSlider->size();
     centerPos.setX(centerPos.x()  - sz.width() / 2);
-    centerPos.setY(centerPos.y() - 35 - sz.height());
+    centerPos.setY(centerPos.y() - this->blurBackground()->rect().height() / 2 - sz.height());
     centerPos = m_volSlider->mapFromGlobal(centerPos);
     centerPos = m_volSlider->mapToParent(centerPos);
     m_volSlider->move(centerPos);
@@ -398,6 +375,7 @@ void FooterWidget::initShortcut()
     connect(nextShortcut, &QShortcut::activated, this, &FooterWidget::slotShortCutTriggered);
     connect(previousShortcut, &QShortcut::activated, this, &FooterWidget::slotShortCutTriggered);
     connect(muteShortcut, &QShortcut::activated, this, &FooterWidget::slotShortCutTriggered);
+    connect(DataBaseService::getInstance(), &DataBaseService::signalCoverUpdate, this, &FooterWidget::slotCoverUpdate);
 }
 
 void FooterWidget::updateShortcut()
@@ -494,6 +472,7 @@ void FooterWidget::slotLyricAutoHidden()
 {
     // 歌词控件自动收起时更新歌词按钮
     m_btLyric->setChecked(false);
+    update();
 }
 
 void FooterWidget::slotPlayClick(bool click)
@@ -523,24 +502,12 @@ void FooterWidget::slotLrcClick(bool click)
 void FooterWidget::slotPlayModeClick(bool click)
 {
     Q_UNUSED(click)
-#ifdef TABLET_PC
-    qDebug() << __FUNCTION__ << "DGuiApplicationHelper::isTabletEnvironment() = " << DGuiApplicationHelper::isTabletEnvironment();
-#endif
+
     int playModel = m_btPlayMode->property("playModel").toInt();
     if (++playModel == 3)
         playModel = 0;
 
     setPlayModel(static_cast<Player::PlaybackMode>(playModel));
-    //更换提示框
-    auto hintWidget = m_btPlayMode->property("HintWidget").value<QWidget *>();
-    m_hintFilter->showHitsFor(m_btPlayMode, hintWidget);
-
-    if (hintWidget != nullptr) {
-        auto hintToolTips = static_cast<ToolTips *>(hintWidget);
-        if (hintToolTips != nullptr) {
-            hintToolTips->setText(playModeStr(playModel));
-        }
-    }
 }
 
 void FooterWidget::slotCoverClick(bool click)
@@ -683,7 +650,7 @@ void FooterWidget::slotMediaMetaChanged(MediaMeta activeMeta)
     }
 }
 
-void FooterWidget::setPlayModel(Player::PlaybackMode playModel)
+void FooterWidget::setPlayModel(Player::PlaybackMode playModel, bool isSignal)
 {
     switch (playModel) {
     case 0:
@@ -699,6 +666,18 @@ void FooterWidget::setPlayModel(Player::PlaybackMode playModel)
         break;
     }
 
+    //更换提示框
+    auto hintWidget = m_btPlayMode->property("HintWidget").value<QWidget *>();
+    if (!isSignal)
+        m_hintFilter->showHitsFor(m_btPlayMode, hintWidget);
+
+    if (hintWidget != nullptr) {
+        auto hintToolTips = static_cast<ToolTips *>(hintWidget);
+        if (hintToolTips != nullptr) {
+            hintToolTips->setText(playModeStr(playModel));
+        }
+    }
+
     m_btPlayMode->setProperty("playModel", QVariant(playModel));
     Player::getInstance()->setMode(static_cast<Player::PlaybackMode>(playModel));
 }
@@ -745,11 +724,6 @@ void FooterWidget::slotFlushSoundIcon()
     m_btSound->update();
 }
 
-//void FooterWidget::slotDelayAutoHide()
-//{
-//    m_btSound->setChecked(false);
-//}
-
 void FooterWidget::slotShortCutTriggered()
 {
     QShortcut *objCut = dynamic_cast<QShortcut *>(sender()) ;
@@ -790,6 +764,66 @@ void FooterWidget::slotShortCutTriggered()
     }
 }
 
+void FooterWidget::slotCoverUpdate(const MediaMeta &meta)
+{
+    MediaMeta curMeta = Player::getInstance()->getActiveMeta();
+    if (curMeta.hash != meta.hash)
+        return;
+
+    QString imagesDirPath = Global::cacheDir() + "/images/" + curMeta.hash + ".jpg";
+    QFileInfo file(imagesDirPath);
+    QIcon icon;
+    if (file.exists()) {
+        icon = QIcon(imagesDirPath);
+        m_btCover->setIcon(icon);
+    } else {
+        m_btCover->setIcon(QIcon::fromTheme("info_cover"));
+    }
+}
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+void FooterWidget::slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode)
+{
+    if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
+        m_btPrev->setFixedSize(32, 24);
+        m_btPlay->setFixedSize(32, 24);
+        m_btNext->setFixedSize(32, 24);
+
+        m_btCover->setFixedSize(24, 24);
+        m_btCover->setIconSize(QSize(24, 24));
+
+        m_title->setMaximumWidth(250);
+
+        m_btFavorite->setFixedSize(24, 24);
+        m_btLyric->setFixedSize(24, 24);
+        m_btPlayMode->setFixedSize(24, 24);
+        m_btSound->setFixedSize(24, 24);
+        m_btPlayQueue->setFixedSize(24, 24);
+
+        this->setContentsMargins(3, 3, 3, 3);
+    } else {
+        m_btPrev->setFixedSize(40, 50);
+        m_btPlay->setFixedSize(40, 50);
+        m_btNext->setFixedSize(40, 50);
+
+        m_btCover->setFixedSize(48, 48);
+        m_btCover->setIconSize(QSize(48, 48));
+
+        m_title->setMaximumWidth(140);
+
+        m_btFavorite->setFixedSize(50, 50);
+        m_btLyric->setFixedSize(50, 50);
+        m_btPlayMode->setFixedSize(50, 50);
+        m_btSound->setFixedSize(50, 50);
+        m_btPlayQueue->setFixedSize(50, 50);
+
+        this->setContentsMargins(6, 6, 6, 6);
+    }
+    // 音量条直接隐藏
+    m_volSlider->hide();
+}
+#endif
+
 void FooterWidget::slotLoadDetector(const QString &hash)
 {
     //查找hash对应路径
@@ -807,8 +841,9 @@ void FooterWidget::slotSetWaveValue(int step, long duration)
 
 void FooterWidget::screenStandby(bool isStandby)
 {
-    if (!Global::boardVendorType())
+    if (!Global::boardVendorType() && !Global::isPangu()) //hw和m900都要阻止锁屏
         return;
+
     if (isStandby) {
         if (m_lastCookie > 0) {
             QDBusInterface iface("org.freedesktop.ScreenSaver",
@@ -839,7 +874,16 @@ void FooterWidget::screenStandby(bool isStandby)
 void FooterWidget::resizeEvent(QResizeEvent *event)
 {
     if (m_forwardWidget) {
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            m_forwardWidget->setGeometry(2, 2, width() - 4, 46);
+        } else {
+            m_forwardWidget->setGeometry(6, 5, width() - 12, 70);
+        }
+#else
         m_forwardWidget->setGeometry(6, height() - 75, width() - 12, 70);
+#endif
+
     }
 
     moveVolSlider();
@@ -890,7 +934,7 @@ void FooterWidget::slotTheme(int type)
         m_forwardWidget->setMaskColor(maskColor);
         rStr = "light";
 
-        auto artistPl = m_artist->palette();
+        QPalette artistPl = m_artist->palette();
         QColor artistColor = artistPl.color(DPalette::BrightText);
         artistColor.setAlphaF(0.4);
         artistPl.setColor(DPalette::WindowText, artistColor);
