@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainframe.h"
 
@@ -52,6 +36,7 @@
 #include <DSettingsOption>
 #include <DApplicationHelper>
 #include <DApplication>
+#include <DSysInfo>
 
 #include <unistd.h>
 #include "./core/musicsettings.h"
@@ -77,6 +62,7 @@
 #include "comdeepiniminterface.h"
 #include "dbusutils.h"
 #include "config.h"
+#include "player.h"
 DWIDGET_USE_NAMESPACE
 
 const QString s_PropertyViewname = "viewname";
@@ -100,11 +86,8 @@ MainFrame::MainFrame()
     this->setWindowTitle(tr("Music"));
 
     m_titlebarwidget = new TitlebarWidget(this);
-//    m_searchResult = new SearchResult(this);
-//    m_titlebarwidget->setResultWidget(m_searchResult);
 
     m_titlebar = new DTitlebar(this);
-    m_titlebar->setFixedHeight(50);
     m_titlebar->setTitle(tr("Music"));
     m_titlebar->setIcon(QIcon::fromTheme("deepin-music"));    //titlebar->setCustomWidget(titlebarwidget, Qt::AlignLeft, false);
 
@@ -114,13 +97,18 @@ MainFrame::MainFrame()
     AC_SET_OBJECT_NAME(m_backBtn, AC_titleBarLeft);
     AC_SET_ACCESSIBLE_NAME(m_backBtn, AC_titleBarLeft);
     m_backBtn->setVisible(false);
-    m_backBtn->setFixedSize(QSize(36, 36));
 
     m_addMusicBtn = new DIconButton(DStyle::SP_IncreaseElement, this);
     m_addMusicBtn->setToolTip(tr("Add music"));
     AC_SET_OBJECT_NAME(m_addMusicBtn, AC_titleBarAddMusic);
     AC_SET_ACCESSIBLE_NAME(m_addMusicBtn, AC_titleBarAddMusic);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    slotSizeModeChanged(DGuiApplicationHelper::instance()->sizeMode());
+#else
+    m_backBtn->setFixedSize(QSize(36, 36));
     m_addMusicBtn->setFixedSize(QSize(36, 36));
+#endif
 
     m_selectStr = tr("Select");
     m_selectAllStr = tr("Select All");
@@ -131,7 +119,6 @@ MainFrame::MainFrame()
     m_backBtn->setIcon(QIcon::fromTheme("left_arrow"));
     m_titlebar->addWidget(m_backBtn, Qt::AlignLeft);
     m_titlebar->addWidget(m_addMusicBtn, Qt::AlignRight);
-    m_titlebar->resize(width(), 50);
 
     // 返回按钮点击
     connect(m_backBtn, &DPushButton::clicked,
@@ -172,6 +159,7 @@ MainFrame::MainFrame()
         show();
         raise();
         activateWindow();
+        this->setWindowState((this->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
     });
 
     connect(CommonService::getInstance(), &CommonService::signalSwitchToView, this, &MainFrame::slotViewChanged);
@@ -188,6 +176,14 @@ MainFrame::MainFrame()
             m_importWidget->slotFileImportProcessing(itemMetas);
         }
     });
+    connect(Player::getInstance(), &Player::signalMediaMetaChanged,
+            this, [=](MediaMeta meta) {
+        this->setWindowTitle(meta.localPath);
+    });
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(),&DGuiApplicationHelper::sizeModeChanged,this, &MainFrame::slotSizeModeChanged);
+#endif
 
     if (CommonService::getInstance()->isTabletEnvironment()) {
         QDBusConnection connection = QDBusConnection::sessionBus();
@@ -250,6 +246,10 @@ void MainFrame::initUI(bool showLoading)
     connect(m_musicLyricWidget, &MusicLyricWidget::signalAutoHidden,
             m_footerWidget, &FooterWidget::slotLyricAutoHidden);
 
+    connect(m_musicLyricWidget, &MusicLyricWidget::signalAutoHidden, m_footerWidget, [=](){
+        m_isLyricShow = false;
+    });
+
     connect(CommonService::getInstance(), &CommonService::signalCdaImportFinished,
             this, &MainFrame::slotCdaImportFinished);
 
@@ -334,7 +334,7 @@ void MainFrame::initMenuAndShortcut()
     nextAction->setEnabled(false);
     auto quitAction = new QAction(tr("Exit"), this);
 
-    auto trayIconMenu = new DMenu(this);
+    DMenu *trayIconMenu = new DMenu(this);
     trayIconMenu->addAction(playAction);
     trayIconMenu->addAction(prevAction);
     trayIconMenu->addAction(nextAction);
@@ -342,7 +342,7 @@ void MainFrame::initMenuAndShortcut()
     trayIconMenu->addAction(quitAction);
 
     //tray icon
-    auto m_sysTrayIcon = new QSystemTrayIcon(this);
+    QSystemTrayIcon *m_sysTrayIcon = new QSystemTrayIcon(this);
     m_sysTrayIcon->setIcon(QIcon::fromTheme("deepin-music"));
     m_sysTrayIcon->setToolTip(tr("Music"));
     m_sysTrayIcon->setContextMenu(trayIconMenu);
@@ -390,8 +390,7 @@ void MainFrame::initMenuAndShortcut()
     });
 #endif
 
-    connect(m_sysTrayIcon, &QSystemTrayIcon::activated,
-    this, [ = ](QSystemTrayIcon::ActivationReason reason) {
+    connect(m_sysTrayIcon, &QSystemTrayIcon::activated, this, [ = ](QSystemTrayIcon::ActivationReason reason) {
         if (QSystemTrayIcon::Trigger == reason) {
             if (checkWindowVisible(Global::isWaylandMode())) {
                 m_preMaxFlag = isMaximized();
@@ -402,8 +401,10 @@ void MainFrame::initMenuAndShortcut()
                 }
                 show();
                 // 特性关闭后需要使用showNormal/showMaximized
-                if (m_preMaxFlag) showMaximized();
-                else showNormal();
+                if (m_preMaxFlag)
+                    showMaximized();
+                else
+                    showNormal();
                 // 使用dbus显示窗口
                 this->titlebar()->setFocus();
                 raise();
@@ -415,11 +416,13 @@ void MainFrame::initMenuAndShortcut()
 
 bool MainFrame::checkWindowVisible(bool waylandMode)
 {
-    if (waylandMode) {
+    const auto minorVersion = DTK_CORE_NAMESPACE::DSysInfo::minorVersion();
+    if (waylandMode && minorVersion.toLong() < 1070) { //1070及以后不需要通过dbus接口判断窗口状态
         QVariant v = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock",
                                                  "com.deepin.dde.daemon.Dock", "Entries");
 
-        if (!v.isValid()) return false;
+        if (!v.isValid())
+            return false;
 
         QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
 
@@ -644,6 +647,40 @@ void MainFrame::slotActiveChanged(bool isActive)
     }
 }
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+void MainFrame::slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode)
+{
+    if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
+        m_backBtn->setFixedSize(QSize(25, 25));
+        m_addMusicBtn->setFixedSize(QSize(25, 25));
+        if (m_footerWidget) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        }
+    } else {
+        if (m_footerWidget) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+        m_backBtn->setFixedSize(QSize(36, 36));
+        m_addMusicBtn->setFixedSize(QSize(36, 36));
+    }
+
+    if (m_musicStatckedWidget) {
+        m_musicStatckedWidget->setGeometry(0, titlebar()->height(), width(), height() - m_footerWidget->height() - titlebar()->height());
+    }
+
+    if (m_musicContentWidget) {
+        m_musicContentWidget->setGeometry(0, titlebar()->height(), width(), height() - m_footerWidget->height() - titlebar()->height());
+    }
+
+    if (m_musicLyricWidget) {
+        m_musicLyricWidget->setGeometry(0, titlebar()->height(), width(), height() - titlebar()->height());
+    }
+    update();
+}
+#endif
+
 void MainFrame::slotSearchEditFoucusIn()
 {
     m_titlebarwidget->slotSearchEditFoucusIn();
@@ -667,6 +704,8 @@ void MainFrame::slotLyricClicked()
         //搜索页面使能
         m_titlebarwidget->setEnabled(true);
     }
+
+    m_isLyricShow = true;
 }
 
 void MainFrame::slotDBImportFinished(QString hash, int successCount)
@@ -1062,8 +1101,18 @@ void MainFrame::showEvent(QShowEvent *event)
     this->setFocus();
 
     if (m_footerWidget) {
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        } else {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+#else
         m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
                                     width() - FooterWidget::Margin * 2, FooterWidget::Height);
+#endif
     }
 
     if (m_importWidget) {
@@ -1096,8 +1145,18 @@ void MainFrame::resizeEvent(QResizeEvent *e)
     }
 
     if (m_footerWidget) {
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        } else {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+#else
         m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
                                     width() - FooterWidget::Margin * 2, FooterWidget::Height);
+#endif
     }
 
     if (m_musicStatckedWidget) {
@@ -1211,6 +1270,32 @@ void MainFrame::hideEvent(QHideEvent *event)
     m_geometryBa = saveGeometry();
 }
 
+void MainFrame::paintEvent(QPaintEvent* e)
+{
+    QPainter painter(this);
+    QRect rect(0, height() - FooterWidget::Height,
+               220, FooterWidget::Height);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        rect.setY(height() - FooterWidget::CompactHeight);
+        rect.setHeight(FooterWidget::CompactHeight);
+    }
+#endif
+
+    QBrush brush(QColor("#FFFFFF"));
+    if (m_isLyricShow) {
+        brush.setColor(Qt::transparent);
+    } else {
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+            brush.setColor("#232323");
+        }
+    }
+
+    painter.fillRect(rect, brush);
+    DMainWindow::paintEvent(e);
+}
+
 void MainFrame::playQueueAnimation()
 {
     if (m_playQueueWidget == nullptr) {
