@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "databaseservice.h"
 #include <algorithm>
@@ -105,7 +89,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY title ASC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_title ASC LIMIT ") + QString::number(count);
         break;
     }
     case DataBaseService::SortBySingerASC: {
@@ -113,7 +97,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY artist ASC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_artist ASC LIMIT ") + QString::number(count);
         break;
     }
     case DataBaseService::SortByAblumASC: {
@@ -121,7 +105,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY album ASC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_album ASC LIMIT ") + QString::number(count);
         break;
     }
     case DataBaseService::SortByAddTimeDES: {
@@ -137,7 +121,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY title DESC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_title DESC LIMIT ") + QString::number(count);
         break;
     }
     case DataBaseService::SortBySingerDES: {
@@ -145,7 +129,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY artist DESC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_artist DESC LIMIT ") + QString::number(count);
         break;
     }
     case DataBaseService::SortByAblumDES: {
@@ -153,7 +137,7 @@ QList<MediaMeta> DataBaseService::getMusicInfosBySortAndCount(int count)
                                  "filetype, track, offset, length, size, "
                                  "timestamp, invalid, search_id, cuepath, "
                                  "lyricPath, codec, py_title, py_artist, py_album "
-                                 "FROM musicNew ORDER BY album DESC LIMIT ") + QString::number(count);
+                                 "FROM musicNew ORDER BY py_album DESC LIMIT ") + QString::number(count);
         break;
     }
     default:
