@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -27,19 +11,19 @@
 #include <DLabel>
 #include <DIconButton>
 #include <DToolButton>
+#include <DGuiApplicationHelper>
 
+DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
 
 class DDropdown : public DWidget
 {
     Q_OBJECT
-    //Q_PROPERTY(QString status READ getStatus WRITE setStatus NOTIFY statusChanged)
 public:
     explicit DDropdown(QWidget *parent = Q_NULLPTR);
     ~DDropdown();
 
-    //QString getStatus() const;
     QList<QAction *> actions() const;
 
 signals:
@@ -52,6 +36,9 @@ public slots:
     void setCurrentAction(int index = 0);
     QAction *addAction(const QString &item, const QVariant &var);
     void setStatus(const QString &status);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    void slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode);
+#endif
 
 protected:
     virtual void enterEvent(QEvent *event);
