@@ -1,34 +1,18 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZouYa <zouya@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
 #include <QHBoxLayout>
+#include <QImage>
 
 #include <DWidget>
 #include <DLabel>
 #include <DBlurEffectWidget>
-#include <QImage>
 
-#include <searchmeta.h>
+#include "searchmeta.h"
 #include "player.h"
 
 DWIDGET_USE_NAMESPACE
@@ -60,7 +44,6 @@ public slots:
     void onProgressChanged(qint64 value, qint64 length);
     void onMusicPlayed(MediaMeta meta);
     void onCoverChanged(MediaMeta meta);
-
     void setThemeType(int type);
 
 protected:
