@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="it" sourcelanguage="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it" sourcelanguage="en_US">
 <context>
     <name>AddMusicWidget</name>
     <message>
@@ -508,7 +506,7 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     <message>
         <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
         <source>Unsupported audio codec</source>
-        <translation type="unfinished"></translation>
+        <translation>Codec audio non supportato</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/mainframe.cpp" line="697"/>
@@ -576,7 +574,7 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
         <source>Custom</source>
-        <translation>Personalizza</translation>
+        <translation>Personalizzazione</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1032"/>
@@ -1218,4 +1216,4 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <translation>Cerca</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
