@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_TW" sourcelanguage="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW" sourcelanguage="en_US">
 <context>
     <name>AddMusicWidget</name>
     <message>
@@ -1217,4 +1215,4 @@
         <translation>搜尋</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
